@@ -4,16 +4,16 @@
 #' a population of random models each one with a random combination of the
 #' provided hyperparameters values.
 #'
-#' @param model \linkS4class{SDMmodel} or \linkS4class{SDMmodelCV} object.
+#' @param model \code{\linkS4class{SDMmodel}} or \code{\linkS4class{SDMmodelCV}}
+#' object.
 #' @param hypers named list containing the values of the hyperparameters that
 #' should be tuned, see details.
 #' @param metric character. The metric used to evaluate the models, possible
 #' values are: "auc", "tss" and "aicc".
-#' @param test \linkS4class{SWD} object. Test dataset used to evaluate the
-#' model, not used with aicc and \linkS4class{SDMmodelCV} objects, default is
-#' \code{NULL}.
-#' @param bg4test \linkS4class{SWD} object or NULL. Background locations used to
-#' get subsamples if **a** hyperparameter is tuned, default is \code{NULL}.
+#' @param test \code{\linkS4class{SWD}} object. Test dataset used to evaluate
+#' the model, not used with aicc and \code{\linkS4class{SDMmodelCV}} objects,
+#' default is \code{NULL}.
+#' @param bg4test Deprecated.
 #' @param pop numeric. Size of the population, default is 20.
 #' @param env \code{\link[raster]{stack}} containing the environmental
 #' variables, used only with "aicc", default is \code{NULL}.
@@ -28,7 +28,7 @@
 #' Parallel computation increases the speed only for large datasets due to the
 #' time necessary to create the cluster.
 #'
-#' @return \linkS4class{SDMtune} object.
+#' @return \code{\linkS4class{SDMtune}} object.
 #' @export
 #'
 #' @author Sergio Vignali
@@ -40,32 +40,28 @@
 #'                     pattern = "grd", full.names = TRUE)
 #' predictors <- raster::stack(files)
 #'
-#' # Prepare presence locations
-#' p_coords <- condor[, 1:2]
-#'
-#' # Prepare background locations
-#' bg_coords <- dismo::randomPoints(predictors, 5000)
+#' # Prepare presence and background locations
+#' p_coords <- virtualSp$presence
+#' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' presence <- prepareSWD(species = "Vultur gryphus", coords = p_coords,
-#'                        env = predictors, categorical = "biome")
-#' bg <- prepareSWD(species = "Vultur gryphus", coords = bg_coords,
-#'                  env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
+#'                    env = predictors, categorical = "biome")
 #'
 #' # Split presence locations in training (80%) and testing (20%) datasets
-#' datasets <- trainValTest(presence, test = 0.2)
+#' datasets <- trainValTest(data, test = 0.2, only_presence = TRUE)
 #' train <- datasets[[1]]
 #' test <- datasets[[2]]
 #'
 #' # Train a model
-#' model <- train(method = "Maxnet", p = train, a = bg, fc = "l")
+#' model <- train(method = "Maxnet", data = train, fc = "l")
 #'
 #' # Define the hyperparameters to test
-#' h <- list(reg = 1:3, fc = c("lqp", "lqph", "lh"), a = seq(3000, 4500, 500))
+#' h <- list(reg = seq(0.2, 3, 0.2), fc = c("lqp", "lqph", "lh"))
 #'
 #' # Run the function using as metric the AUC
 #' output <- randomSearch(model, hypers = h, metric = "auc", test = test,
-#'                        bg4test = bg, pop = 10, seed = 25)
+#'                        pop = 10, seed = 25)
 #' output@results
 #' output@models
 #' # Order rusults by highest test AUC
@@ -74,11 +70,16 @@
 randomSearch <- function(model, hypers, metric, test = NULL, bg4test = NULL,
                          pop = 20, env = NULL, parallel = FALSE, seed = NULL) {
 
+  # TODO remove it next release
+  if (!is.null(bg4test))
+    warning("Argument \"bg4test\" is deprecated and ignored, it will be ",
+            "removed in the next release.")
+
   metric <- match.arg(metric, choices = c("auc", "tss", "aicc"))
 
-  output <- optimizeModel(model = model, hypers = hypers, bg4test = bg4test,
-                          test = test, metric = metric, pop = pop, gen = 0,
-                          env = env, parallel = parallel, seed = seed)
+  output <- optimizeModel(model = model, hypers = hypers, test = test,
+                          metric = metric, pop = pop, gen = 0, env = env,
+                          parallel = parallel, seed = seed)
 
   return(output)
 }
